pyparsing.pyparsing.ParseExpression

Package pyparsing :: Module pyparsing :: Class ParseExpression |
[frames] | no frames]

# Class ParseExpression

source code

       object --+
                |
    ParserElement --+
                    |
                   ParseExpression

Known Subclasses:
  - And
  - , Each
  - , MatchFirst
  - , Or

Abstract subclass of ParserElement, for combining and post-processing parsed tokens.

Instance Methods
__init__(self, exprs, savelist=False) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__getitem__(self, i) | source code
append(self, other) | source code
leaveWhitespace(self) Extends leaveWhitespace defined in base class, and also invokes leaveWhitespace on all contained expressions. | source code
ignore(self, other) Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns. | source code
__str__(self) str(x) | source code
streamline(self) | source code
setResultsName(self, name, listAllMatches=False) Define name for referencing matching tokens as a nested attribute of the returned parse results. | source code
validate(self, validateTrace=`[``]`) Check defined expressions for valid structure, check for infinite recursive definitions. | source code
Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__hash__`, `__invert__`, `__mul__`, `__ne__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__rne__`, `__ror__`, `__rsub__`, `__rxor__`, `__sub__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `getException`, `parseFile`, `parseImpl`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setName`, `setParseAction`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`, `verbose_stacktrace`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, exprs, savelist=False) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### leaveWhitespace(self) | source code
Extends leaveWhitespace defined in base class, and also invokes leaveWhitespace on all contained expressions. Overrides: ParserElement.leaveWhitespace

### ignore(self, other) | source code
Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns. Overrides: ParserElement.ignore (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### streamline(self) | source code
Overrides: ParserElement.streamline

### setResultsName(self, name, listAllMatches=False) | source code
Define name for referencing matching tokens as a nested attribute of the returned parse results. NOTE: this returns a *copy* of the original `ParserElement` object; this is so that the client can define a basic element, such as an integer, and reference it in multiple places with different names. You can also set results names using the abbreviated syntax, `expr("name")` in place of `expr.setResultsName("name")` - see __call__. Overrides: ParserElement.setResultsName (inherited documentation)

### validate(self, validateTrace=`[``]`) | source code
Check defined expressions for valid structure, check for infinite recursive definitions. Overrides: ParserElement.validate (inherited documentation)